summaryrefslogtreecommitdiffstats
path: root/karm/task.h
diff options
context:
space:
mode:
Diffstat (limited to 'karm/task.h')
-rw-r--r--karm/task.h29
1 files changed, 15 insertions, 14 deletions
diff --git a/karm/task.h b/karm/task.h
index 200612ae..acf2cd99 100644
--- a/karm/task.h
+++ b/karm/task.h
@@ -13,7 +13,7 @@
#include "desktoplist.h"
// Required b/c of static cast below? (How else can compiler know that a
-// TaskView is a subclass or QListView?)
+// TaskView is a subclass or TQListView?)
#include "taskview.h"
class TQFile;
@@ -38,27 +38,28 @@ class TQPixmap;
* It can also contain subtasks - these are managed using the
* TQListViewItem class.
*/
-class Task : public TQObject, public QListViewItem
+class Task : public TQObject, public TQListViewItem
{
Q_OBJECT
+ TQ_OBJECT
public:
//@{ constructors
Task( const TQString& taskame, long minutes, long sessionTime,
- DesktopList desktops, TaskView* parent = 0);
+ DesktopList desktops, TaskView* tqparent = 0);
Task( const TQString& taskame, long minutes, long sessionTime,
- DesktopList desktops, Task* parent = 0);
- Task( KCal::Todo* incident, TaskView* parent );
+ DesktopList desktops, Task* tqparent = 0);
+ Task( KCal::Todo* incident, TaskView* tqparent );
//@}
/* destructor */
~Task();
/** return parent Task or null in case of TaskView.
* same as TQListViewItem::parent()
*/
Task* firstChild() const { return (Task*)TQListViewItem::firstChild(); }
Task* nextSibling() const { return (Task*)TQListViewItem::nextSibling(); }
- Task* parent() const { return (Task*)TQListViewItem::parent(); }
+ Task* tqparent() const { return (Task*)TQListViewItem::tqparent(); }
/** Return task view for this task */
TaskView* taskView() const {
@@ -77,9 +78,9 @@ class Task : public TQObject, public QListViewItem
*/
void setUid(const TQString uid);
/** cut Task out of parent Task or the TaskView */
void cut();
/** cut Task out of parent Task or the TaskView and into the
* destination Task */
void move(Task* destination);
/** insert Task into the destination Task */
@@ -161,7 +162,7 @@ class Task : public TQObject, public QListViewItem
TQString name() const { return _name; };
/**
* Returns that task name, prefixed by parent tree up to root.
*
* Task names are seperated by a forward slash: /
*/
@@ -205,9 +206,9 @@ class Task : public TQObject, public QListViewItem
TQString comment() const;
/** tells you whether this task is the root of the task tree */
- bool isRoot() const { return parent() == 0; }
+ bool isRoot() const { return tqparent() == 0; }
- /** remove Task with all it's children
+ /** remove Task with all it's tqchildren
* @param activeTasks - list of aktive tasks
* @param storage a pointer to a KarmStorage object.
*/
@@ -230,7 +231,7 @@ class Task : public TQObject, public QListViewItem
/** Return true if task is complete (percent complete equals 100). */
bool isComplete();
- /** Remove current task and all it's children from the view. */
+ /** Remove current task and all it's tqchildren from the view. */
void removeFromView();
/** delivers when the task was started last */
@@ -38,27 +38,28 @@ class TQPixmap;
/* destructor */
~Task();
- /** return parent Task or null in case of TaskView.
- * same as TQListViewItem::parent()
+ /** return tqparent Task or null in case of TaskView.
+ * same as TQListViewItem::tqparent()
*/
Task* firstChild() const { return (Task*)TQListViewItem::firstChild(); }
@@ -77,9 +78,9 @@ class Task : public TQObject, public QListViewItem
*/
void setUid(const TQString uid);
- /** cut Task out of parent Task or the TaskView */
+ /** cut Task out of tqparent Task or the TaskView */
void cut();
@@ -77,9 +78,9 @@ class Task : public TQObject, public QListViewItem
void cut();
- /** cut Task out of parent Task or the TaskView and into the
+ /** cut Task out of tqparent Task or the TaskView and into the
* destination Task */
void move(Task* destination);
@@ -161,7 +162,7 @@ class Task : public TQObject, public QListViewItem
TQString name() const { return _name; };
/**
- * Returns that task name, prefixed by parent tree up to root.
+ * Returns that task name, prefixed by tqparent tree up to root.
*
* Task names are seperated by a forward slash: /